# Pandora Storage Server Python Client 🪐🐍

This is the Python Client implementation for the Key-Value Pairs Schemaless Pandora Storage Server.

How to Install Pandora Storage Server Python Client
==========

*Requirements: 
- Python 3.6+ installed.

Make sure you have Python 3.6+ installed and run the following command in your terminal to install the Pandora Storage Server Python Client:

For MacOS and GNU/Linux:

```python
pip3 install pandora_storage_server_client
```

For Windows:

```python
pip install pandora_storage_server_client
```

How to use the Pandora Storage Server Python Client
==========

To use the client import the client module to your Python script as follows:

```python
import pandora_storage_server_client as pandora
```